@@ -1,7 +1,7 @@
 <?php
 
 spl_autoload_register(function ($class) {
-    if (strpos($class, 'ZxcvbnPhp\\') !== 0) {
+    if (strpos($class, 'ZxcvbnPhp\\') !== false) {
         include(
             __DIR__ . DIRECTORY_SEPARATOR .
             str_replace(
